@@ -48,13 +48,18 @@ from octobot_tentacles_manager.api.configurator import (
     unregister_tentacle_packages,
     update_activation_configuration,
     save_tentacles_setup_configuration,
+    has_profile_local_configuration,
     get_activated_tentacles,
     update_tentacle_config,
+    import_user_tentacles_config_folder,
     get_tentacle_config,
     factory_tentacle_reset_config,
     get_tentacle_config_schema_path,
     get_compiled_tentacles_url,
+    set_tentacles_setup_configuration_path,
     ensure_setup_configuration,
+    get_code_hash,
+    get_config_hash,
 )
 from octobot_tentacles_manager.api.updater import (
     update_all_tentacles,
@@ -71,9 +76,11 @@ from octobot_tentacles_manager.api.inspector import (
     get_tentacle_version,
     get_tentacle_origin_package,
     get_tentacle_module_name,
+    get_tentacle_classes_requirements,
     get_tentacle_resources_path,
     get_tentacle_documentation_path,
     check_tentacle_version,
+    get_tentacle_class_from_string,
 )
 from octobot_tentacles_manager.api.uninstaller import (
     uninstall_all_tentacles,
@@ -101,12 +108,17 @@ __all__ = [
     "unregister_tentacle_packages",
     "update_activation_configuration",
     "save_tentacles_setup_configuration",
+    "has_profile_local_configuration",
     "get_activated_tentacles",
     "update_tentacle_config",
     "get_tentacle_config",
+    "import_user_tentacles_config_folder",
     "factory_tentacle_reset_config",
     "get_tentacle_config_schema_path",
     "get_compiled_tentacles_url",
+    "set_tentacles_setup_configuration_path",
+    "get_code_hash",
+    "get_config_hash",
     "ensure_setup_configuration",
     "update_all_tentacles",
     "update_tentacles",
@@ -118,9 +130,11 @@ __all__ = [
     "get_tentacle_version",
     "get_tentacle_origin_package",
     "get_tentacle_module_name",
+    "get_tentacle_classes_requirements",
     "get_tentacle_resources_path",
     "get_tentacle_documentation_path",
     "check_tentacle_version",
+    "get_tentacle_class_from_string",
     "uninstall_all_tentacles",
     "uninstall_tentacles",
     "start_tentacle_creator",
