@@ -14,6 +14,7 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 import os.path as path
+import sys
 
 import octobot_commons.tentacles_management as tentacles_management
 
@@ -95,6 +96,10 @@ def save_tentacles_setup_configuration(tentacles_setup_config: configuration.Ten
     tentacles_setup_config.save_config()
 
 
+def has_profile_local_configuration(tentacles_setup_config: configuration.TentaclesSetupConfiguration, tentacle_class):
+    return path.exists(configuration.get_profile_config_specific_file_path(tentacles_setup_config, tentacle_class))
+
+
 def get_activated_tentacles(tentacles_setup_config: configuration.TentaclesSetupConfiguration) -> list:
     return [tentacle_class
             for tentacle_classes in tentacles_setup_config.tentacles_activation.values()
@@ -107,6 +112,12 @@ def update_tentacle_config(tentacles_setup_config: configuration.TentaclesSetupC
     configuration.update_config(tentacles_setup_config, tentacle_class, config_data)
 
 
+def import_user_tentacles_config_folder(tentacles_setup_config: configuration.TentaclesSetupConfiguration):
+    user_tentacles_config_folder = configuration.get_user_tentacles_config_folder(tentacles_setup_config)
+    if path.isdir(user_tentacles_config_folder) and user_tentacles_config_folder not in sys.path:
+        sys.path.append(user_tentacles_config_folder)
+
+
 def get_tentacle_config(tentacles_setup_config: configuration.TentaclesSetupConfiguration, klass) -> dict:
     return configuration.get_config(tentacles_setup_config, klass)
 
@@ -121,3 +132,16 @@ def get_tentacle_config_schema_path(klass) -> str:
 
 def get_compiled_tentacles_url(base_url, version) -> str:
     return f"{base_url}{util.get_local_arch_download_path()}/{version}.zip"
+
+
+def set_tentacles_setup_configuration_path(tentacles_setup_config: configuration.TentaclesSetupConfiguration, new_path):
+    tentacles_setup_config.config_path = new_path
+
+
+def get_code_hash(tentacles: list) -> str:
+    return util.get_tentacles_code_hash(tentacles)
+
+
+def get_config_hash(tentacles: list,
+                    tentacles_setup_config: configuration.TentaclesSetupConfiguration) -> str:
+    return util.get_tentacles_config_hash(tentacles, tentacles_setup_config)
