@@ -31,6 +31,7 @@ class TentaclesSetupConfiguration:
     DEFAULT_DEACTIVATABLE_TENTACLE_SUB_TYPES = {
         constants.TENTACLES_EVALUATOR_REALTIME_PATH,
         constants.TENTACLES_EVALUATOR_TA_PATH,
+        constants.TENTACLES_EVALUATOR_SCRIPTED_PATH,
         constants.TENTACLES_EVALUATOR_SOCIAL_PATH,
         constants.TENTACLES_EVALUATOR_STRATEGIES_PATH,
         constants.TENTACLES_TRADING_MODE_PATH,
@@ -77,8 +78,9 @@ class TentaclesSetupConfiguration:
         bot_profiles_path = os.path.join(self.bot_installation_path, profiles_path)
         if path.isdir(bot_profiles_path):
             for profile_folder in os.scandir(bot_profiles_path):
-                self._refresh_profile_tentacles_config(tentacles, profile_folder,
-                                                       newly_installed_tentacles, uninstalled_tentacles)
+                if profile_folder.is_dir():
+                    self._refresh_profile_tentacles_config(tentacles, profile_folder,
+                                                           newly_installed_tentacles, uninstalled_tentacles)
 
     def update_activation_configuration(self, new_config, deactivate_other_evaluators,
                                         add_missing_elements, tentacles_path=constants.TENTACLES_PATH):
@@ -138,7 +140,8 @@ class TentaclesSetupConfiguration:
             if loaders.get_tentacle_classes()[element_name].get_simple_tentacle_type() in {
                 constants.TENTACLES_EVALUATOR_TA_PATH,
                 constants.TENTACLES_EVALUATOR_SOCIAL_PATH,
-                constants.TENTACLES_EVALUATOR_REALTIME_PATH
+                constants.TENTACLES_EVALUATOR_REALTIME_PATH,
+                constants.TENTACLES_EVALUATOR_SCRIPTED_PATH
             }:
                 self.logger.info(f"Tentacles configuration updated: {element_name} {'deactivated'}")
                 self.tentacles_activation[element_type][element_name] = False
