@@ -19,7 +19,10 @@ import os
 import os.path as path
 import shutil
 
+import aiofiles
 import octobot_commons.logging as logging
+import yaml
+
 import octobot_tentacles_manager.models as models
 import octobot_tentacles_manager.constants as constants
 import octobot_tentacles_manager.creators as creators
@@ -36,7 +39,8 @@ class ArtifactExporter:
                  output_dir: str = constants.DEFAULT_EXPORT_DIR,
                  should_cythonize: bool = False,
                  should_zip: bool = False,
-                 with_dev_mode: bool = False):
+                 with_dev_mode: bool = False,
+                 use_package_as_file_name: bool = False):
         self.logger = logging.get_logger(self.__class__.__name__)
         self.artifact = artifact
         self.tentacles_folder: str = tentacles_folder
@@ -46,6 +50,7 @@ class ArtifactExporter:
         self.should_cythonize = should_cythonize
         self.should_zip = should_zip
         self.with_dev_mode = with_dev_mode
+        self.use_package_as_file_name = use_package_as_file_name
 
         self.artifact.output_dir = self.output_dir
         self.artifact.output_path = os.path.join(self.output_dir, self.artifact.name)
@@ -60,6 +65,14 @@ class ArtifactExporter:
         """
         raise NotImplementedError("prepare_export is not implemented")
 
+    @abc.abstractmethod
+    async def get_metadata_instance(self) -> models.ArtifactMetadata:
+        """
+        Called after prepare_export, should be implemented if a metadata file has to be created
+        :return: an ArtifactMetadata instance
+        """
+        raise NotImplementedError("get_metadata_instance is not implemented")
+
     @abc.abstractmethod
     async def after_export(self) -> None:
         """
@@ -72,12 +85,14 @@ class ArtifactExporter:
         """
         Run artifact export process by calling :
         - export preparation with abstract prepare_export()
+        - create metadata file if necessary
         - export cleanup, cythonization and compression with cleanup_cythonize_and_archive_if_necessary()
         - export finalization with abstract after_export()
         :return: an error code as integer (0 for success and 1 for fail)
         """
         try:
             await self.prepare_export()
+            await self.create_metadata_file()
             await self.cleanup_cythonize_and_archive_if_necessary()
             await self.after_export()
             return 0
@@ -99,7 +114,7 @@ class ArtifactExporter:
 
         # Zip if required
         if self.should_zip:
-            self.artifact.output_path = self.zip_working_folder()
+            self.artifact.output_path = self.zip_temporary_folder()
             self.logger.info(f"Zipped {self.artifact.ARTIFACT_NAME} available at: {self.artifact.output_path}")
         else:
             self.artifact.output_path = os.path.abspath(self.working_folder)
@@ -150,19 +165,54 @@ class ArtifactExporter:
         else:
             util.merge_folders(folder_to_copy, self.working_folder, ignore)
 
-    def zip_working_folder(self) -> str:
+    def zip_temporary_folder(self) -> str:
         """
         Archive creator temporary dir to a zip file
         :return: the path of the archive
         """
-        # remove .zip extension if necessary
-        file_name = self.artifact.name.split(f".{constants.TENTACLES_PACKAGE_FORMAT}")[0].\
-            replace(models.TentaclePackage.ARTIFACT_VERSION_SEPARATOR, "_")
-        zipped_file = shutil.make_archive(os.path.join(self.artifact.output_dir, file_name),
-                                          constants.TENTACLES_PACKAGE_FORMAT, self.working_folder)
+        zipped_file = shutil.make_archive(os.path.join(self.artifact.output_dir, self.get_zip_file_name()),
+                                          constants.TENTACLES_PACKAGE_FORMAT,
+                                          constants.TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER)
         try:
             # remove working folder
             shutil.rmtree(constants.TENTACLES_PACKAGE_CREATOR_TEMP_FOLDER)
         except Exception as e:
             self.logger.error(f"Error when cleaning up temporary folder: {e}")
         return zipped_file
+
+    def get_zip_file_name(self) -> str:
+        """
+        Set package name using artifact name or platform data when cythonized and remove .zip extension if necessary
+        :return: the zip file name
+        """
+        return self.get_exported_file_name().split(f".{constants.TENTACLES_PACKAGE_FORMAT}")[0]. \
+            replace(constants.ARTIFACT_VERSION_SEPARATOR, "_")
+
+    def get_exported_file_name(self) -> str:
+        """
+        return: the export file name depending on compilation and self.use_package_as_file_name value
+        """
+        if self.use_package_as_file_name:
+            return self.artifact.name
+        if self.should_cythonize:
+            return f"{util.get_os_str()}_{util.get_arch_str()}"
+        return constants.ANY_PLATFORM_FILE_NAME
+
+    def get_metadata_file_path(self) -> str:
+        """
+        :return: the metadata destination file path
+        """
+        return os.path.abspath(self.working_folder)
+
+    async def create_metadata_file(self) -> None:
+        """
+        Creates metadata file from artifacts count
+        :return: None
+        """
+        try:
+            artifact_metadata: models.ArtifactMetadata = await self.get_metadata_instance()
+            async with aiofiles.open(os.path.join(self.get_metadata_file_path(),
+                                                  constants.ARTIFACT_METADATA_FILE), "w") as metadata_file:
+                await metadata_file.write(yaml.dump(artifact_metadata.to_dict()))
+        except NotImplementedError:
+            pass  # Metadata file creation is ignored
