@@ -19,6 +19,7 @@ import os
 import os.path as path
 import shutil
 
+import octobot_commons.aiohttp_util as aiohttp_util
 import octobot_tentacles_manager.constants as constants
 import octobot_tentacles_manager.util as util
 
@@ -50,16 +51,12 @@ def get_local_arch_download_path():
 
 
 async def _download_tentacles(target_file, download_URL, aiohttp_session):
-    async with aiohttp_session.get(download_URL) as resp:
-        async with aiofiles.open(target_file, 'wb+') as downloaded_file:
-            if resp.status != 200:
-                raise RuntimeError(f"Can't find tentacle archive at: {download_URL} (status: {resp.status})")
-            while True:
-                chunk = await resp.content.read(DOWNLOADED_DATA_CHUNK_SIZE)
-                if not chunk:
-                    # resp.content.read returns an empty chunk when completed
-                    break
-                await downloaded_file.write(chunk)
+    async with aiofiles.open(target_file, 'wb+') as downloaded_file:
+        await aiohttp_util.download_stream_file(output_file=downloaded_file,
+                                                file_url=download_URL,
+                                                aiohttp_session=aiohttp_session,
+                                                data_chunk_size=DOWNLOADED_DATA_CHUNK_SIZE,
+                                                is_aiofiles_output_file=True)
 
 
 async def _extract_tentacles(source_path, target_path, merge_dirs):
